============
Installation
============

PyPI
====

The Python package is available on the Python Package Index (PyPI) as
``fedora-messaging``::

    $ pip install --user fedora-messaging

It is, of course, recommended that you install it in a Python virtual
environment.


Fedora
======

The library is not yet packaged for Fedora. When it is, it will be available
as ``python-fedora-messaging``.
